@@ -4,7 +4,8 @@ test_that("extract distinct id works", {
   
   input<-data.frame(cbind(c("3","6","1203","141414","3","3","3","1203","1203"),
                           sample(1:9),
-                          c(rep("a",3),rep("b",4),rep("a",2))))
+                          c(rep("a",3),rep("b",4),rep("a",2))),
+                    stringsAsFactors = F)
   colnames(input)<-c("people","grade","group")
   output<-as.numeric(levels(input$people))
 
